==> knative-model-6.7.1-sources.jar: io/fabric8/knative/flows/v1/ParallelChannelStatusBuilder.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ParallelChannelStatusBuilder extends ParallelChannelStatusFluentImpl<ParallelChannelStatusBuilder> implements VisitableBuilder<ParallelChannelStatus,ParallelChannelStatusBuilder>{
  public ParallelChannelStatusBuilder() {
    this(false);
  }
  public ParallelChannelStatusBuilder(Boolean validationEnabled) {
    this(new ParallelChannelStatus(), validationEnabled);
  }
  public ParallelChannelStatusBuilder(ParallelChannelStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ParallelChannelStatusBuilder(ParallelChannelStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ParallelChannelStatus(), validationEnabled);
  }
  public ParallelChannelStatusBuilder(ParallelChannelStatusFluent<?> fluent,ParallelChannelStatus instance) {
    this(fluent, instance, false);
  }
  public ParallelChannelStatusBuilder(ParallelChannelStatusFluent<?> fluent,ParallelChannelStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withChannel(instance.getChannel());
      fluent.withReady(instance.getReady());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ParallelChannelStatusBuilder(ParallelChannelStatus instance) {
    this(instance,false);
  }
  public ParallelChannelStatusBuilder(ParallelChannelStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withChannel(instance.getChannel());
      this.withReady(instance.getReady());
    }
    this.validationEnabled = validationEnabled; 
  }
  ParallelChannelStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ParallelChannelStatus build() {
    ParallelChannelStatus buildable = new ParallelChannelStatus(fluent.getChannel(),fluent.getReady());
    return buildable;
  }
  
}

==> knative-model-6.8.0-sources.jar: io/fabric8/knative/flows/v1/ParallelChannelStatusBuilder.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ParallelChannelStatusBuilder extends ParallelChannelStatusFluent<ParallelChannelStatusBuilder> implements VisitableBuilder<ParallelChannelStatus,ParallelChannelStatusBuilder>{
  public ParallelChannelStatusBuilder() {
    this(false);
  }
  public ParallelChannelStatusBuilder(Boolean validationEnabled) {
    this(new ParallelChannelStatus(), validationEnabled);
  }
  public ParallelChannelStatusBuilder(ParallelChannelStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ParallelChannelStatusBuilder(ParallelChannelStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ParallelChannelStatus(), validationEnabled);
  }
  public ParallelChannelStatusBuilder(ParallelChannelStatusFluent<?> fluent,ParallelChannelStatus instance) {
    this(fluent, instance, false);
  }
  public ParallelChannelStatusBuilder(ParallelChannelStatusFluent<?> fluent,ParallelChannelStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ParallelChannelStatus());

    if (instance != null) {
      fluent.withChannel(instance.getChannel());
      fluent.withReady(instance.getReady());
      fluent.withChannel(instance.getChannel());
      fluent.withReady(instance.getReady());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ParallelChannelStatusBuilder(ParallelChannelStatus instance) {
    this(instance,false);
  }
  public ParallelChannelStatusBuilder(ParallelChannelStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ParallelChannelStatus());

    if (instance != null) {
      this.withChannel(instance.getChannel());
      this.withReady(instance.getReady());
      this.withChannel(instance.getChannel());
      this.withReady(instance.getReady());
    }
    this.validationEnabled = validationEnabled; 
  }
  ParallelChannelStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ParallelChannelStatus build() {
    ParallelChannelStatus buildable = new ParallelChannelStatus(fluent.buildChannel(),fluent.buildReady());
    return buildable;
  }
  
}
